@@ -223,13 +223,14 @@ Vue.component('item-form', {
     }
 });
 
-var app = new Vue({
+var app = window.Yancy = new Vue({
     el: '#app',
     data: function () {
         var current = this.parseHash();
         return {
             hasSchema: null,
             currentSchemaName: current.schema || null,
+            currentComponent: null,
             schema: {},
             openedRow: null,
             deleteIndex: null,
@@ -305,9 +306,14 @@ var app = new Vue({
 
         setSchema: function ( name ) {
             this.currentSchemaName = name;
+            this.currentComponent = null;
             $( '#sidebar-collapse' ).collapse('hide');
         },
 
+        setComponent: function ( name ) {
+            this.currentComponent = name;
+        },
+
         fetchSpec: function () {
             var self = this;
             delete self.error.fetchSpec;
